==> gtick-0.2.2.tar.gz: gtick-0.2.2/src/mixer.c <==
/*
 * mixer.c: Sound mixer code, for volume type stuff
 *
 * This file is part of GTick
 *
 *
 * Copyright (c) 1999, Alex Roberts
 * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
 *
 * GTick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GTick is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GTick; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

/* GNU headers */
#include <unistd.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#ifdef FREEBSD
#include <machine/soundcard.h>
#else
#include <linux/soundcard.h>
#endif

/* GTK+ headers */
#include <glib.h>

/* own headers */
#include "globals.h"
#include "metro.h"
#include "mixer.h"

static gint mix;
static gchar devName[] = "/dev/mixer";

void gtInitMixer()
{

  if (debug)
    g_print ("gtInitMixer: Initialising %s..\n", devName);
	
  if ((mix = open (devName, O_RDWR, 0)) == -1)
    {
      g_error ("Couldn't open mixer device /dev/mixer\n");
      exit (1);
    }
	 
}

void gtCloseMixer()
{
  if (debug)
    g_print ("gtCloseMixer: Closing /dev/mixer..\n");

  close (mix);
}


gint gtGetMixer()
{
  gint vol, r, l;
  
  ioctl (mix, MIXER_READ(SOUND_MIXER_PCM), &vol);
  
  l = vol & 0xff;
  r = (vol & 0xff00) >> 8;

  if (debug)
    g_print ("gtGetMixer: vol=%d, l=%d, r=%d\n", vol, l, r);
  
  return (r+l)/2;
}

void gtSetMixer (gint vol)
{
  gint tvol;
  
  tvol = (vol << 8) + vol;

  if (debug)
    g_print ("gtSetMixer: Setting mixer value: %d\n", tvol);

  ioctl (mix, MIXER_WRITE(SOUND_MIXER_PCM), &tvol);
}

==> gtick-0.2.3.tar.gz: gtick-0.2.3/src/mixer.c <==
/*
 * mixer.c: Sound mixer code, for volume type stuff
 *
 * This file is part of GTick
 *
 *
 * Copyright (c) 1999, Alex Roberts
 * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
 *
 * GTick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GTick is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GTick; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include <config.h>

/* GNU headers */
#include <unistd.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#ifdef FREEBSD
#include <machine/soundcard.h>
#else
#include <linux/soundcard.h>
#endif

/* GTK+ headers */
#include <glib.h>

/* own headers */
#include "globals.h"
#include "metro.h"
#include "mixer.h"

static gint mix;
static gchar devName[] = "/dev/mixer";

void gtInitMixer()
{

  if (debug)
    g_print ("gtInitMixer: Initialising %s...\n", devName);
	
  if ((mix = open (devName, O_RDWR, 0)) == -1)
    {
      g_error ("Couldn't open mixer device /dev/mixer\n");
      exit (1);
    }
	 
}

void gtCloseMixer()
{
  if (debug)
    g_print ("gtCloseMixer: Closing /dev/mixer..\n");

  close (mix);
}


gint gtGetMixer()
{
  gint vol, r, l;
  
  ioctl (mix, MIXER_READ(SOUND_MIXER_PCM), &vol);
  
  l = vol & 0xff;
  r = (vol & 0xff00) >> 8;

  if (debug)
    g_print ("gtGetMixer: vol=%d, l=%d, r=%d\n", vol, l, r);
  
  return (r+l)/2;
}

void gtSetMixer (gint vol)
{
  gint tvol;
  
  tvol = (vol << 8) + vol;

  if (debug)
    g_print ("gtSetMixer: Setting mixer value: 0x%04X\n", tvol);

  ioctl (mix, MIXER_WRITE(SOUND_MIXER_PCM), &tvol);
}
